aboutsummaryrefslogtreecommitdiffstats
path: root/contrib/edioutput/Transport.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'contrib/edioutput/Transport.cpp')
-rw-r--r--contrib/edioutput/Transport.cpp11
1 files changed, 7 insertions, 4 deletions
diff --git a/contrib/edioutput/Transport.cpp b/contrib/edioutput/Transport.cpp
index cfed9ec..f8e5dc7 100644
--- a/contrib/edioutput/Transport.cpp
+++ b/contrib/edioutput/Transport.cpp
@@ -132,11 +132,14 @@ void Sender::write(const TagPacket& tagpacket)
edi_fragments.size());
}
/* Spread out the transmission of all fragments over 75% of the 24ms AF packet duration
* to reduce the risk of losing fragments because of congestion.
*
- * 75% was chosen so that other outputs still have time to do their thing. */
- const auto inter_fragment_wait_time = std::chrono::microseconds(llrint(0.75 * 24000.0 / edi_fragments.size()));
+ * 25% was chosen so that other outputs still have time to do their thing. */
+ auto inter_fragment_wait_time = std::chrono::microseconds(0);
+ if (edi_fragments.size() > 1) {
+ inter_fragment_wait_time = std::chrono::microseconds(llrint(0.25 * 24000.0 / edi_fragments.size()));
+ }
// Send over ethernet
for (auto& edi_frag : edi_fragments) {
@@ -132,11 +132,14 @@ void Sender::write(const TagPacket& tagpacket)
edi_fragments.size());
}
- /* Spread out the transmission of all fragments over 75% of the 24ms AF packet duration
- * to reduce the risk of losing fragments because of congestion.
+ /* Spread out the transmission of all fragments over 25% of the 24ms AF packet duration
+ * to reduce the risk of losing a burst of fragments because of congestion.
*